@@ -1,6 +1,7 @@
 from pybrary.func import todo
 
-from . import info
+from setux.logger import info
+
 from .manage import Manager
 
 
